@@ -309,7 +309,7 @@ class Print(Effect):
             If False, this will redraw all characters and so replace any Effect underneath it.
         :param speed: The refresh rate in frames between refreshes.
 
-        Note that a spped of 1 will force the Screen to redraw the Effect every frame update, while a value
+        Note that a speed of 1 will force the Screen to redraw the Effect every frame update, while a value
         of 0 will redraw on demand - i.e. will redraw every time that an update is required by another Effect.
 
         Also see the common keyword arguments in :py:obj:`.Effect`.
@@ -377,9 +377,10 @@ class Mirage(Effect):
         self._renderer = renderer
         self._y = y
         self._colour = colour
+        self._count = 0
 
     def reset(self):
-        pass
+        self._count = 0
 
     def _update(self, frame_no):
         if frame_no % 2 == 0:
@@ -1119,3 +1120,34 @@ class Julia(Effect):
     @property
     def stop_frame(self):
         return self._stop_frame
+
+
+class Background(Effect):
+    """
+    Effect to be used as a Desktop background.  This sets the background to the specified
+    colour.
+    """
+
+    def __init__(self, screen, bg=0, **kwargs):
+        """
+        :param screen: The Screen being used for the Scene.
+        :param bg: Optional colour for the background.
+
+        Also see the common keyword arguments in :py:obj:`.Effect`.
+        """
+        super(Background, self).__init__(screen, **kwargs)
+        self._bg = bg
+
+    def reset(self):
+        pass
+
+    def _update(self, frame_no):
+        self._screen.clear_buffer(7, 0, self._bg)
+
+    @property
+    def frame_update_count(self):
+        return 1000000
+
+    @property
+    def stop_frame(self):
+        return self._stop_frame
