@@ -21,6 +21,7 @@ import re
 from wcwidth.wcwidth import wcswidth
 
 from asciimatics.screen import Screen
+from asciimatics.constants import COLOUR_REGEX
 
 
 #: Attribute conversion table for the ${c,a} form of attributes for
@@ -48,8 +49,7 @@ class Renderer(with_metaclass(ABCMeta, object)):
     @abstractproperty
     def max_width(self):
         """
-        :return: The max width of the rendered text (across all images if an
-            animated renderer).
+        :return: The max width of the rendered text (across all images if an animated renderer).
         """
 
     @abstractproperty
@@ -67,8 +67,7 @@ class Renderer(with_metaclass(ABCMeta, object)):
     @abstractproperty
     def max_height(self):
         """
-        :return: The max height of the rendered text (across all images if an
-            animated renderer).
+        :return: The max height of the rendered text (across all images if an animated renderer).
         """
 
     def __repr__(self):
@@ -91,8 +90,7 @@ class StaticRenderer(Renderer):
 
     # Regular expression for use to find colour sequences in multi-colour text.
     # It should match ${n}, ${m,n} or ${m,n,o}
-    _colour_esc_code = r"^\$\{((\d+),(\d+),(\d+)|(\d+),(\d+)|(\d+))\}(.*)"
-    _colour_sequence = re.compile(_colour_esc_code)
+    _colour_sequence = re.compile(COLOUR_REGEX)
 
     def __init__(self, images=None, animation=None):
         """
@@ -179,8 +177,7 @@ class StaticRenderer(Renderer):
     @property
     def max_height(self):
         """
-        :return: The max height of the rendered text (across all images if an
-            animated renderer).
+        :return: The max height of the rendered text (across all images if an animated renderer).
         """
         if len(self._plain_images) <= 0:
             self._convert_images()
@@ -193,8 +190,7 @@ class StaticRenderer(Renderer):
     @property
     def max_width(self):
         """
-        :return: The max width of the rendered text (across all images if an
-            animated renderer).
+        :return: The max width of the rendered text (across all images if an animated renderer).
         """
         if len(self._plain_images) <= 0:
             self._convert_images()
@@ -473,17 +469,21 @@ class SpeechBubble(StaticRenderer):
         if uni:
             bubble = "╭─" + "─" * max_len + "─╮\n"
             for line in text.split("\n"):
-                bubble += "│ " + line + " │\n"
-            bubble += "╰─" + "─" * max_len + "─╯\n"
+                filler = " " * (max_len - len(line))
+                bubble += "│ " + line + filler + " │\n"
+            bubble += "╰─" + "─" * max_len + "─╯"
         else:
             bubble = ".-" + "-" * max_len + "-.\n"
             for line in text.split("\n"):
-                bubble += "| " + line + " |\n"
-            bubble += "`-" + "-" * max_len + "-`\n"
+                filler = " " * (max_len - len(line))
+                bubble += "| " + line + filler + " |\n"
+            bubble += "`-" + "-" * max_len + "-`"
         if tail == "L":
+            bubble += "\n"
             bubble += "  )/  \n"
             bubble += "-\"`\n"
         elif tail == "R":
+            bubble += "\n"
             bubble += (" " * max_len) + "\\(  \n"
             bubble += (" " * max_len) + " `\"-\n"
         self._images = [bubble]
