@@ -6,7 +6,13 @@ from __future__ import division
 from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
+from builtins import str
 from datetime import date, datetime
+from logging import getLogger
+
+
+# Diagnostic logging
+logger = getLogger(__name__)
 
 
 def readable_mem(mem):
