@@ -102,7 +102,7 @@ class TestRenderers(unittest.TestCase):
         self.assertEqual(str(renderer),
                          ".-------.\n" +
                          "| hello |\n" +
-                         "`-------`\n")
+                         "`-------`")
 
         # Left bubble.
         renderer = SpeechBubble("world", tail="L")
@@ -127,7 +127,24 @@ class TestRenderers(unittest.TestCase):
         self.assertEqual(str(renderer),
                          u"╭───────╮\n"
                          u"│ hello │\n"
-                         u"╰───────╯\n")
+                         u"╰───────╯")
+
+        # Multiline text rendering
+        text = "Hello\n" \
+               "World! \n" \
+               "Hello World!"
+
+        renderer = SpeechBubble(text, uni=True)
+        self.assertEqual(str(renderer),
+                         "╭──────────────╮\n" +
+                         "│ Hello        │\n" +
+                         "│ World!       │\n" +
+                         "│ Hello World! │\n" +
+                         "╰──────────────╯")
+
+        # Test render height
+        renderer = SpeechBubble("Hello World", uni=True)
+        self.assertEqual(renderer.max_height, 3)
 
     def test_box(self):
         """
@@ -163,19 +180,20 @@ class TestRenderers(unittest.TestCase):
 
         # Check an image looks plausible
         image = next(renderer.images)
+        self.maxDiff = None
         self.assertEqual(
             image,
             ['',
-             '        .:;rA       ',
-             '    :2HG#;H2;s;;2   ',
-             '  .::#99&G@@hsr;;s3 ',
-             ' .:;;9&@@@Hrssrrr;22',
-             's.:;;;@Hs2GArsssrrr#',
-             '..:;;;rrsGA&&Gsrrr;r',
-             ' .:;;;;rsr@@@@@@Hs;:',
-             ' ;.:;;;;rrA@@@@@G;: ',
-             '   .::;;;;;2&9G:;:  ',
-             '     ..:::;Gr::s    '])
+             '     sA3h3h3Hr2     ',
+             '  ;:;G#99G@&2;;;r   ',
+             ' .::#9&&@@G;rrrr;;3 ',
+             '.:;;A&@AAGsssssrr;#H',
+             '.:;;;r29@srssssrr;A2',
+             '.::;;rrrrr@@@@9;r;;A',
+             's.:;;;;rr2@@@@@@#;; ',
+             ' s.::;;;;;;9&&&3;:  ',
+             '   ..::;;;;9#r::2   ',
+             '      s...r.;       '])
 
     def test_colour_image_file(self):
         """
@@ -185,6 +203,8 @@ class TestRenderers(unittest.TestCase):
         # This typically means we're running inside a non-standard terminal.
         # For example, this happens when embedded in PyCharm.
         if sys.platform != "win32":
+            if not (("FORCE_TTY" in os.environ and os.environ["FORCE_TTY"] == "Y") or sys.stdout.isatty()):
+                self.skipTest("Not a valid TTY")
             curses.initscr()
             if curses.tigetstr("ri") is None:
                 self.skipTest("No valid terminal definition")
@@ -206,19 +226,20 @@ class TestRenderers(unittest.TestCase):
 
             # Check an image looks plausible
             image = next(renderer.images)
+            self.maxDiff = None
             self.assertEqual(
                 image,
                 ['',
-                 '        #####       ',
-                 '    #############   ',
-                 '  ################# ',
-                 ' ###################',
-                 '####################',
-                 '####################',
-                 ' ###################',
+                 '     ##########     ',
+                 '  ###############   ',
                  ' ################## ',
-                 '   ###############  ',
-                 '     ###########    '])
+                 '####################',
+                 '####################',
+                 '####################',
+                 '################### ',
+                 ' #################  ',
+                 '   ##############   ',
+                 '      #######       '])
 
             # Also check the BG rendering
             renderer2 = ColourImageFile(
@@ -254,6 +275,8 @@ class TestRenderers(unittest.TestCase):
         # This typically means we're running inside a non-standard terminal.
         # For example, this happens when embedded in PyCharm.
         if sys.platform != "win32":
+            if not (("FORCE_TTY" in os.environ and os.environ["FORCE_TTY"] == "Y") or sys.stdout.isatty()):
+                self.skipTest("Not a valid TTY")
             curses.initscr()
             if curses.tigetstr("ri") is None:
                 self.skipTest("No valid terminal definition")
@@ -278,16 +301,16 @@ class TestRenderers(unittest.TestCase):
             self.assertEqual(
                 image,
                 ['.',
-                 '.....▄▄▄▄▄▄▄▄▄▄......',
-                 '...▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄...',
+                 '....▄▄▄▄▄▄▄▄▄▄▄▄.....',
+                 '..▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄...',
                  '.▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄..',
-                 '.▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄.',
                  '▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄.',
                  '▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄.',
-                 '.▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄.',
+                 '▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄.',
+                 '▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄..',
                  '.▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄..',
-                 '...▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄...',
-                 '.....▄▄▄▄▄▄▄▄▄▄▄.....'])
+                 '..▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄....',
+                 '.....▄▄▄▄▄▄▄▄▄▄......'])
 
         Screen.wrapper(internal_checks, height=15)
 
@@ -298,14 +321,18 @@ class TestRenderers(unittest.TestCase):
         # Skip for non-Windows if the terminal definition is incomplete.
         # This typically means we're running inside a non-standard terminal.
         # For example, this happens when embedded in PyCharm.
-        if sys.platform != "win32" and curses.tigetstr("ri") is None:
-            self.skipTest("No valid terminal definition")
+        if sys.platform != "win32":
+            if not (("FORCE_TTY" in os.environ and os.environ["FORCE_TTY"] == "Y") or sys.stdout.isatty()):
+                self.skipTest("Not a valid TTY")
+            curses.initscr()
+            if curses.tigetstr("ri") is None:
+                self.skipTest("No valid terminal definition")
 
         def internal_checks(screen):
             # Create a base renderer
             plain_text = (".-------.\n" +
                           "| hello |\n" +
-                          "`-------`\n")
+                          "`-------`")
             renderer = SpeechBubble("hello")
             self.assertEqual(str(renderer), plain_text)
 
@@ -324,8 +351,7 @@ class TestRenderers(unittest.TestCase):
                     [(1, 1, None), (3, 1, None), (3, 1, None), (2, 1, None), (2, 1, None),
                      (6, 1, None), (6, 1, None), (4, 1, None), (4, 1, None)],
                     [(3, 1, None), (3, 1, None), (2, 1, None), (2, 1, None), (6, 1, None),
-                     (6, 1, None), (4, 1, None), (4, 1, None), (5, 1, None)],
-                    []])
+                     (6, 1, None), (4, 1, None), (4, 1, None), (5, 1, None)]])
 
         Screen.wrapper(internal_checks, height=15)
 
