@@ -9,6 +9,7 @@ from mock import MagicMock
 from random import randint
 import unittest
 import sys
+import time
 from builtins import str
 from builtins import chr
 from builtins import bytes
@@ -19,7 +20,7 @@ try:
 except ImportError:
     pass
 from asciimatics.scene import Scene
-from asciimatics.screen import Screen, Canvas, ManagedScreen
+from asciimatics.screen import Screen, Canvas, ManagedScreen, _DoubleBuffer
 from tests.mock_objects import MockEffect
 if sys.platform == "win32":
     import win32console
@@ -46,6 +47,8 @@ class TestScreen(unittest.TestCase):
         # This typically means we're running inside a non-standard terminal.
         # For example, this happens when embedded in PyCharm.
         if sys.platform != "win32":
+            if not (("FORCE_TTY" in os.environ and os.environ["FORCE_TTY"] == "Y") or sys.stdout.isatty()):
+                self.skipTest("Not a valid TTY")
             curses.initscr()
             if curses.tigetstr("ri") is None:
                 self.skipTest("No valid terminal definition")
@@ -105,8 +108,8 @@ class TestScreen(unittest.TestCase):
             for x in range(screen.width):
                 for y in range(15):
                     char = randint(0, 255)
-                    fg = randint(0, Screen.COLOUR_WHITE)
-                    bg = randint(0, Screen.COLOUR_WHITE)
+                    fg = randint(Screen.COLOUR_DEFAULT, Screen.COLOUR_WHITE)
+                    bg = randint(Screen.COLOUR_DEFAULT, Screen.COLOUR_WHITE)
                     attr = randint(0, Screen.A_UNDERLINE)
                     screen.print_at(chr(char), x, y, fg, attr, bg)
                     char2, fg2, attr2, bg2 = screen.get_from(x, y)
@@ -570,6 +573,11 @@ class TestScreen(unittest.TestCase):
             screen.draw_next_frame()
             self.assertTrue(test_effect.update_called)
 
+            # Now check that a full refresh works.
+            self.assertEqual(len(list(screen._buffer.deltas(0, 100))), 0)
+            screen.force_update(full_refresh=True)
+            self.assertGreater(len(list(screen._buffer.deltas(0, 100))), 0)
+
         Screen.wrapper(internal_checks, height=15)
 
     def test_catch_exceptions(self):
@@ -824,6 +832,17 @@ class TestScreen(unittest.TestCase):
 
         Screen.wrapper(internal_checks, height=15)
 
+    def test_wait(self):
+        """
+        Check that wait_for_input delays as requested when no input.
+        """
+        def internal_checks(screen):
+            start = time.time()
+            screen.wait_for_input(0.1)
+            self.assertGreaterEqual(time.time() - start, 0.1)
+
+        Screen.wrapper(internal_checks, height=15)
+
     def test_ctrl(self):
         """
         Check that ctrl returns the right values.
@@ -963,6 +982,24 @@ class TestScreen(unittest.TestCase):
         canvas.print_at("cd", canvas.width - 1, 0)
         self.assert_line_equals(canvas, "b                                      c")
 
+    def test_double_buffer(self):
+        """
+        Check _DoubleBuffer works.
+        """
+        buffer = _DoubleBuffer(20, 10)
+
+        # Check clear works
+        self.assertEqual(buffer._double_buffer[0][0], (' ', 7, 0, 0, 1))
+        self.assertEqual(buffer._double_buffer[19][9], (' ', 7, 0, 0, 1))
+        buffer.clear(1, 0, 2)
+        self.assertEqual(buffer._double_buffer[0][0], (' ', 1, 0, 2, 1))
+        self.assertEqual(buffer._double_buffer[19][9], (' ', 1, 0, 2, 1))
+
+        # Check clear clips as needed.
+        buffer.clear(3, 1, 4, x=1, y=1, w=100, h=100)
+        self.assertEqual(buffer._double_buffer[0][0], (' ', 1, 0, 2, 1))
+        self.assertEqual(buffer._double_buffer[19][9], (' ', 3, 1, 4, 1))
+
     def test_context_manager(self):
         """
         Check ManagedScreen context manager works.
