@@ -9,7 +9,7 @@ import unittest
 from asciimatics.utilities import readable_mem, readable_timestamp
 
 
-class TestWidgets(unittest.TestCase):
+class TestUtilities(unittest.TestCase):
 
     def test_readable_mem(self):
         """
@@ -33,3 +33,4 @@ class TestWidgets(unittest.TestCase):
             time.mktime(datetime.now().replace(hour=0, minute=1, second=2).timetuple())))
         self.assertEquals("1999-01-02", readable_timestamp(
             time.mktime(datetime.now().replace(year=1999, month=1, day=2).timetuple())))
+
